@@ -184,10 +184,11 @@ use File::Glob qw(:case);
     },
 
     'bignum' => {
-        'DISTRIBUTION' => 'PJACKLAM/bignum-0.41.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/bignum-0.42.tar.gz',
         'FILES'        => q[cpan/bignum],
         'EXCLUDED'     => [
             qr{^inc/Module/},
+            qr{^t/author-},
             qw( t/00sig.t
                 t/01load.t
                 t/02pod.t
@@ -386,12 +387,10 @@ use File::Glob qw(:case);
     },
 
     'Encode' => {
-        'DISTRIBUTION' => 'DANKOGAI/Encode-2.78.tar.gz',
+        'DISTRIBUTION' => 'DANKOGAI/Encode-2.80.tar.gz',
         'FILES'        => q[cpan/Encode],
         CUSTOMIZED     => [
-            qw( Encode.xs
-                Unicode/Unicode.xs
-                encoding.pm
+            qw( encoding.pm
                 ),
         ],
     },
@@ -484,6 +483,40 @@ use File::Glob qw(:case);
             qq[t/vstrings.t],
         # Upstreamed as https://github.com/Perl-Toolchain-Gang/ExtUtils-MakeMaker/commit/dd1e236ab
             qq[lib/ExtUtils/MM_VMS.pm],
+        # Not yet submitted
+            qq[t/lib/MakeMaker/Test/NoXS.pm],
+        # Backported commits from upstream
+            qw(lib/ExtUtils/Command/MM.pm
+               lib/ExtUtils/Liblist.pm
+               lib/ExtUtils/Liblist/Kid.pm
+               lib/ExtUtils/MM.pm
+               lib/ExtUtils/MM_AIX.pm
+               lib/ExtUtils/MM_Any.pm
+               lib/ExtUtils/MM_BeOS.pm
+               lib/ExtUtils/MM_Cygwin.pm
+               lib/ExtUtils/MM_DOS.pm
+               lib/ExtUtils/MM_Darwin.pm
+               lib/ExtUtils/MM_MacOS.pm
+               lib/ExtUtils/MM_NW5.pm
+               lib/ExtUtils/MM_OS2.pm
+               lib/ExtUtils/MM_QNX.pm
+               lib/ExtUtils/MM_UWIN.pm
+               lib/ExtUtils/MM_Unix.pm
+               lib/ExtUtils/MM_VOS.pm
+               lib/ExtUtils/MM_Win32.pm
+               lib/ExtUtils/MM_Win95.pm
+               lib/ExtUtils/MY.pm
+               lib/ExtUtils/MakeMaker/Config.pm
+               lib/ExtUtils/MakeMaker/FAQ.pod
+               lib/ExtUtils/MakeMaker/Tutorial.pod
+               lib/ExtUtils/MakeMaker/version.pm
+               lib/ExtUtils/MakeMaker/version/regex.pm
+               lib/ExtUtils/Mkbootstrap.pm
+               lib/ExtUtils/Mksymlists.pm
+               lib/ExtUtils/testlib.pm
+               t/cd.t
+               t/echo.t
+               ),
         ],
     },
 
@@ -656,6 +689,14 @@ use File::Glob qw(:case);
                 const-xs.inc
                 ),
         ],
+        'CUSTOMIZED' => [
+            # CPAN #118827
+	    qw(t/ipcsysv.t
+               lib/IPC/Msg.pm
+               lib/IPC/Semaphore.pm
+               lib/IPC/SharedMem.pm
+               lib/IPC/SysV.pm),
+        ],
     },
 
     'JSON::PP' => {
@@ -674,7 +715,7 @@ use File::Glob qw(:case);
     },
 
     'libnet' => {
-        'DISTRIBUTION' => 'SHAY/libnet-3.07.tar.gz',
+        'DISTRIBUTION' => 'SHAY/libnet-3.08.tar.gz',
         'FILES'        => q[cpan/libnet],
         'EXCLUDED'     => [
             qw( Configure
@@ -721,11 +762,12 @@ use File::Glob qw(:case);
     },
 
     'Math::BigInt' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-1.999710.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-1.999715.tar.gz',
         'FILES'        => q[cpan/Math-BigInt],
         'EXCLUDED'     => [
             qr{^inc/},
             qr{^examples/},
+            qr{^t/author-},
             qw( t/00sig.t
                 t/01load.t
                 t/02pod.t
@@ -735,7 +777,7 @@ use File::Glob qw(:case);
     },
 
     'Math::BigInt::FastCalc' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-FastCalc-0.38.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-FastCalc-0.40.tar.gz',
         'FILES'        => q[cpan/Math-BigInt-FastCalc],
         'EXCLUDED'     => [
             qr{^inc/},
@@ -758,7 +800,7 @@ use File::Glob qw(:case);
     },
 
     'Math::BigRat' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigRat-0.260801.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigRat-0.260802.tar.gz',
         'FILES'        => q[cpan/Math-BigRat],
         'EXCLUDED'     => [
             qr{^inc/},
@@ -766,6 +808,7 @@ use File::Glob qw(:case);
                 t/01load.t
                 t/02pod.t
                 t/03podcov.t
+                t/blog-mbr.t
                 ),
         ],
         'CUSTOMIZED'   => [
@@ -797,7 +840,7 @@ use File::Glob qw(:case);
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20151120.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20160121.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
@@ -859,7 +902,7 @@ use File::Glob qw(:case);
     },
 
     'PathTools' => {
-        'DISTRIBUTION' => 'RJBS/PathTools-3.60.tar.gz',
+        'DISTRIBUTION' => 'RJBS/PathTools-3.62.tar.gz',
         'FILES'        => q[dist/PathTools],
         'EXCLUDED'     => [
             qr{^t/lib/Test/},
@@ -928,30 +971,18 @@ use File::Glob qw(:case);
     },
 
     'Pod::Usage' => {
-        'DISTRIBUTION' => 'MAREKR/Pod-Usage-1.67.tar.gz',
+        'DISTRIBUTION' => 'MAREKR/Pod-Usage-1.68.tar.gz',
         'FILES'        => q[cpan/Pod-Usage],
     },
 
     'podlators' => {
-        'DISTRIBUTION' => 'RRA/podlators-2.5.3.tar.gz',
+        'DISTRIBUTION' => 'RRA/podlators-4.06.tar.gz',
         'FILES'        => q[cpan/podlators pod/perlpodstyle.pod],
 
-        # The perl distribution has pod2man.PL and pod2text.PL,  which are
-        # run to create pod2man and pod2text, while the CPAN distribution
-        # just has the post-generated pod2man and pod2text files.
-        # The following entries attempt to codify that odd fact.
-        'CUSTOMIZED' => [
-            qw( scripts/pod2man.PL
-                scripts/pod2text.PL
-                ),
-        ],
         'MAP' => {
             ''                 => 'cpan/podlators/',
-            'scripts/pod2man'  => 'cpan/podlators/scripts/pod2man.PL',
-            'scripts/pod2text' => 'cpan/podlators/scripts/pod2text.PL',
-
             # this file lives outside the cpan/ directory
-            'pod/perlpodstyle.pod' => 'pod/perlpodstyle.pod',
+            'pod/perlpodstyle' => 'pod/perlpodstyle.pod',
         },
     },
 
@@ -965,12 +996,14 @@ use File::Glob qw(:case);
         'FILES'        => q[cpan/Scalar-List-Utils],
         # Waiting to be merged upstream:
         # https://github.com/Scalar-List-Utils/Scalar-List-Utils/pull/24
+        # https://rt.cpan.org/Public/Bug/Display.html?id=105415
         'CUSTOMIZED'   => [
             qw( ListUtil.xs
                 lib/List/Util.pm
                 lib/List/Util/XS.pm
                 lib/Scalar/Util.pm
                 lib/Sub/Util.pm
+                t/product.t
                 )
         ],
     },
@@ -992,6 +1025,7 @@ use File::Glob qw(:case);
 
         # https://rt.cpan.org/Ticket/Display.html?id=106797
         # https://rt.cpan.org/Ticket/Display.html?id=107058
+        # https://rt.cpan.org/Ticket/Display.html?id=111707
         'CUSTOMIZED'   => [ qw[ Socket.pm Socket.xs ] ],
     },
 
@@ -1055,16 +1089,13 @@ use File::Glob qw(:case);
     },
 
     'Test::Harness' => {
-        'DISTRIBUTION' => 'LEONT/Test-Harness-3.35.tar.gz',
+        'DISTRIBUTION' => 'LEONT/Test-Harness-3.36.tar.gz',
         'FILES'        => q[cpan/Test-Harness],
         'EXCLUDED'     => [
             qr{^examples/},
-            qr{^inc/},
-            qr{^t/lib/Test/},
             qr{^xt/},
             qw( Changes-2.64
                 MANIFEST.CUMMULATIVE
-                NotBuild.PL
                 HACKING.pod
                 perlcriticrc
                 t/000-load.t
@@ -1189,7 +1220,7 @@ use File::Glob qw(:case);
 
     'Time::HiRes' => {
         'DISTRIBUTION' => 'RJBS/Time-HiRes-1.9728.tar.gz',
-        'FILES'        => q[cpan/Time-HiRes],
+        'FILES'        => q[dist/Time-HiRes],
     },
 
     'Time::Local' => {
@@ -1220,12 +1251,19 @@ use File::Glob qw(:case);
     },
 
     'Unicode::Normalize' => {
-        'DISTRIBUTION' => 'KHW/Unicode-Normalize-1.24.tar.gz',
+        'DISTRIBUTION' => 'KHW/Unicode-Normalize-1.25.tar.gz',
         'FILES'        => q[cpan/Unicode-Normalize],
+        'EXCLUDED'     => [
+            qw( MANIFEST.N
+                Normalize.pmN
+                disableXS
+                enableXS
+                ),
+        ],
     },
 
     'version' => {
-        'DISTRIBUTION' => 'JPEACOCK/version-0.9909.tar.gz',
+        'DISTRIBUTION' => 'JPEACOCK/version-0.9916.tar.gz',
         'FILES'        => q[cpan/version vutil.c vutil.h vxs.inc],
         'EXCLUDED' => [
             qr{^vutil/lib/},
@@ -1271,26 +1309,11 @@ use File::Glob qw(:case);
     },
 
     'Win32API::File' => {
-        'DISTRIBUTION' => 'CHORNY/Win32API-File-0.1202.tar.gz',
+        'DISTRIBUTION' => 'CHORNY/Win32API-File-0.1203.tar.gz',
         'FILES'        => q[cpan/Win32API-File],
         'EXCLUDED'     => [
             qr{^ex/},
         ],
-
-        # Currently all EOL differences. Waiting for a new upstream release:
-        # All the files in the GitHub repo have UNIX EOLs already.
-        'CUSTOMIZED'   => [
-            qw( ExtUtils/Myconst2perl.pm
-                Makefile.PL
-                buffers.h
-                cFile.h
-                cFile.pc
-                const2perl.h
-                t/file.t
-                t/tie.t
-                typemap
-                ),
-        ],
     },
 
     'XSLoader' => {
