@@ -6,8 +6,8 @@ afs='false'
 afsroot='/afs'
 alignbytes='4'
 aphostname='/bin/hostname'
-archlib='/usr/local/lib/perl5/5.21/unknown'
-archlibexp='/usr/local/lib/perl5/5.21/unknown'
+archlib='/usr/local/lib/perl5/5.23/unknown'
+archlibexp='/usr/local/lib/perl5/5.23/unknown'
 archname='unknown'
 asctime_r_proto='0'
 bin='/usr/local/bin'
@@ -50,6 +50,8 @@ d_alarm='undef'
 d_archlib='undef'
 d_asctime64='undef'
 d_asctime_r='undef'
+d_asinh='undef'
+d_atanh='undef'
 d_atolf='undef'
 d_atoll='undef'
 d_attribute_deprecated='undef'
@@ -72,6 +74,7 @@ d_bzero='undef'
 d_c99_variadic_macros='undef'
 d_casti32='undef'
 d_castneg='undef'
+d_cbrt='undef'
 d_charvspr='undef'
 d_chown='undef'
 d_chroot='undef'
@@ -81,6 +84,7 @@ d_clearenv='undef'
 d_closedir='define'
 d_cmsghdr_s='undef'
 d_const='undef'
+d_copysign='undef'
 d_copysignl='undef'
 d_cplusplus='undef'
 d_crypt='undef'
@@ -120,7 +124,11 @@ d_endpwent_r='undef'
 d_endsent='undef'
 d_endservent_r='undef'
 d_eofnblk='undef'
+d_erf='undef'
+d_erfc='undef'
 d_eunice='undef'
+d_exp2='undef'
+d_expm1='undef'
 d_faststdio='undef'
 d_fchdir='undef'
 d_fchmod='undef'
@@ -129,6 +137,8 @@ d_fcntl='undef'
 d_fcntl_can_lock='undef'
 d_fd_macros='undef'
 d_fd_set='undef'
+d_fdclose='undef'
+d_fdim='undef'
 d_fds_bits='undef'
 d_fegetround='undef'
 d_fgetpos='undef'
@@ -137,6 +147,9 @@ d_finitel='undef'
 d_flexfnam='undef'
 d_flock='undef'
 d_flockproto='undef'
+d_fma='undef'
+d_fmax='undef'
+d_fmin='undef'
 d_fork='define'
 d_fp_class='undef'
 d_fp_classify='undef'
@@ -147,6 +160,7 @@ d_fpclassify='undef'
 d_fpclassl='undef'
 d_fpgetround='undef'
 d_fpos64_t='undef'
+d_freelocale='undef'
 d_frexpl='undef'
 d_fs_data_s='undef'
 d_fseeko='undef'
@@ -224,6 +238,8 @@ d_gnulibc='undef'
 d_grpasswd='undef'
 d_hasmntopt='undef'
 d_htonl='undef'
+d_hypot='undef'
+d_ilogb='undef'
 d_ilogbl='undef'
 d_inc_version_list='undef'
 d_index='undef'
@@ -241,8 +257,10 @@ d_isfinite='undef'
 d_isfinitel='undef'
 d_isinf='undef'
 d_isinfl='undef'
+d_isless='undef'
 d_isnan='undef'
 d_isnanl='undef'
+d_isnormal='undef'
 d_j0='undef'
 d_j0l='undef'
 d_killpg='undef'
@@ -250,15 +268,28 @@ d_lc_monetary_2008='undef'
 d_lchown='undef'
 d_ldbl_dig='undef'
 d_ldexpl='undef'
+d_lgamma='undef'
+d_lgamma_r='undef'
 d_libm_lib_version='undef'
 d_link='undef'
+d_llrint='undef'
+d_llrintl='undef'
+d_llround='undef'
+d_llroundl='undef'
 d_localtime64='undef'
 d_localtime_r='undef'
 d_localtime_r_needs_tzset='undef'
 d_locconv='undef'
 d_lockf='undef'
+d_log1p='undef'
+d_log2='undef'
+d_logb='undef'
 d_longdbl='undef'
 d_longlong='undef'
+d_lrint='undef'
+d_lrintl='undef'
+d_lround='undef'
+d_lroundl='undef'
 d_lseekproto='undef'
 d_lstat='undef'
 d_madvise='undef'
@@ -298,7 +329,12 @@ d_msgsnd='undef'
 d_msync='undef'
 d_munmap='undef'
 d_mymalloc='undef'
+d_nan='undef'
 d_ndbm_h_uses_prototypes='undef'
+d_nearbyint='undef'
+d_newlocale='undef'
+d_nextafter='undef'
+d_nexttoward='undef'
 d_nice='undef'
 d_nl_langinfo='undef'
 d_nv_preserves_uv='undef'
@@ -341,13 +377,19 @@ d_readdir_r='undef'
 d_readlink='undef'
 d_readv='undef'
 d_recvmsg='undef'
+d_regcomp='define'
+d_remainder='undef'
+d_remquo='undef'
 d_rename='define'
 d_rewinddir='undef'
+d_rint='undef'
 d_rmdir='undef'
+d_round='undef'
 d_safebcpy='undef'
 d_safemcpy='undef'
 d_sanemcmp='undef'
 d_sbrkproto='undef'
+d_scalbn='undef'
 d_scalbnl='undef'
 d_sched_yield='undef'
 d_scm_rights='undef'
@@ -399,6 +441,13 @@ d_shmctl='undef'
 d_shmdt='undef'
 d_shmget='undef'
 d_sigaction='undef'
+d_siginfo_si_addr='undef'
+d_siginfo_si_band='undef'
+d_siginfo_si_errno='undef'
+d_siginfo_si_pid='undef'
+d_siginfo_si_status='undef'
+d_siginfo_si_uid='undef'
+d_siginfo_si_value='undef'
 d_signbit='undef'
 d_sigprocmask='undef'
 d_sigsetjmp='undef'
@@ -419,6 +468,7 @@ d_srand48_r='undef'
 d_srandom_r='undef'
 d_sresgproto='undef'
 d_sresuproto='undef'
+d_stat='define'
 d_statblks='undef'
 d_statfs_f_flags='undef'
 d_statfs_s='undef'
@@ -461,12 +511,14 @@ d_tcgetpgrp='undef'
 d_tcsetpgrp='undef'
 d_telldir='undef'
 d_telldirproto='undef'
+d_tgamma='undef'
 d_time='define'
 d_timegm='undef'
 d_times='undef'
 d_tm_tm_gmtoff='undef'
 d_tm_tm_zone='undef'
 d_tmpnam_r='undef'
+d_trunc='undef'
 d_truncate='undef'
 d_truncl='undef'
 d_ttyname_r='undef'
@@ -478,6 +530,7 @@ d_uname='undef'
 d_union_semun='undef'
 d_unordered='undef'
 d_unsetenv='undef'
+d_uselocale='undef'
 d_usleep='undef'
 d_usleepproto='undef'
 d_ustat='undef'
@@ -505,6 +558,10 @@ db_version_major='0'
 db_version_minor='0'
 db_version_patch='0'
 direntrytype='struct dirent'
+doubleinfbytes='0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f'
+doublekind='3'
+doublemantbits='52'
+doublenanbytes='0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x7f'
 doublesize='8'
 drand01="Perl_drand48()"
 drand48_r_proto='0'
@@ -663,7 +720,10 @@ ivtype='long'
 ld_can_script='define'
 lib_ext='.a'
 localtime_r_proto='0'
+longdblinfbytes='0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00'
 longdblkind=0
+longdblmantbits='64'
+longdblnanbytes='0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00'
 longdblsize=8
 longlongsize=8
 longsize='4'
@@ -688,6 +748,7 @@ nv_preserves_uv_bits='0'
 nveformat='"e"'
 nvfformat='"f"'
 nvgformat='"g"'
+nvmantbits='52'
 nvsize='8'
 nvtype='double'
 o_nonblock='O_NONBLOCK'
@@ -702,8 +763,8 @@ package='perl5'
 perl_static_inline='static'
 phostname='hostname'
 pidtype=int
-privlib='/usr/local/lib/perl5/5.21'
-privlibexp='/usr/local/lib/perl5/5.21'
+privlib='/usr/local/lib/perl5/5.23'
+privlibexp='/usr/local/lib/perl5/5.23'
 procselfexe=''
 prototype='undef'
 ptrsize='4'
@@ -753,11 +814,11 @@ sig_name_init='0'
 sig_num_init='0'
 sig_size='1'
 signal_t=int
-sitearch='/usr/local/lib/perl5/5.21/unknown'
-sitearchexp='/usr/local/lib/perl5/5.21/unknown'
-sitelib='/usr/local/lib/perl5/5.21'
+sitearch='/usr/local/lib/perl5/5.23/unknown'
+sitearchexp='/usr/local/lib/perl5/5.23/unknown'
+sitelib='/usr/local/lib/perl5/5.23'
 sitelib_stem='/usr/local/lib/perl5'
-sitelibexp='/usr/local/lib/perl5/5.21'
+sitelibexp='/usr/local/lib/perl5/5.23'
 sizesize=4
 sizetype='size_t'
 socksizetype='int'
