@@ -138,6 +138,7 @@ d_fcntl='undef'
 d_fcntl_can_lock='undef'
 d_fd_macros='undef'
 d_fd_set='undef'
+d_fdclose='undef'
 d_fdim='undef'
 d_fds_bits='undef'
 d_fegetround='undef'
@@ -160,6 +161,7 @@ d_fpclassify='undef'
 d_fpclassl='undef'
 d_fpgetround='undef'
 d_fpos64_t='undef'
+d_freelocale='undef'
 d_frexpl='undef'
 d_fs_data_s='undef'
 d_fseeko='undef'
@@ -331,6 +333,7 @@ d_mymalloc='undef'
 d_nan='undef'
 d_ndbm_h_uses_prototypes='undef'
 d_nearbyint='undef'
+d_newlocale='undef'
 d_nextafter='undef'
 d_nexttoward='undef'
 d_nice='undef'
@@ -439,6 +442,13 @@ d_shmctl='undef'
 d_shmdt='undef'
 d_shmget='undef'
 d_sigaction='undef'
+d_siginfo_si_addr='undef'
+d_siginfo_si_band='undef'
+d_siginfo_si_errno='undef'
+d_siginfo_si_pid='undef'
+d_siginfo_si_status='undef'
+d_siginfo_si_uid='undef'
+d_siginfo_si_value='undef'
 d_signbit='undef'
 d_sigprocmask='undef'
 d_sigsetjmp='undef'
@@ -521,6 +531,7 @@ d_uname='undef'
 d_union_semun='undef'
 d_unordered='undef'
 d_unsetenv='undef'
+d_uselocale='undef'
 d_usleep='undef'
 d_usleepproto='undef'
 d_ustat='undef'
